==> com.liferay.faces.bridge.impl-4.1.3-sources.jar: com/liferay/faces/bridge/el/internal/ELResolverCompatImpl.java <==
/**
 * Copyright (c) 2000-2019 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.el.internal;

import java.beans.FeatureDescriptor;
import java.util.Collections;
import java.util.List;

import javax.el.ELContext;
import javax.el.ELResolver;
import javax.faces.FacesWrapper;
import javax.faces.context.FacesContext;
import javax.portlet.PortletConfig;
import javax.portlet.PortletRequest;
import javax.portlet.PortletResponse;


/**
 * This class provides a compatibility layer that isolates differences between JSF versions.
 *
 * @author  Neil Griffin
 */
public abstract class ELResolverCompatImpl extends ELResolver {

	// Protected Constants
	protected static final List<FeatureDescriptor> FEATURE_DESCRIPTORS_COMPAT;

	static {

		// Initialize the list of static feature descriptors.
		FEATURE_DESCRIPTORS_COMPAT = Collections.unmodifiableList(Collections.EMPTY_LIST);
	}

	protected static FeatureDescriptor getFeatureDescriptor(String featureName, Class<?> classType) {
		FeatureDescriptor featureDescriptor = new FeatureDescriptor();
		featureDescriptor.setName(featureName);
		featureDescriptor.setDisplayName(featureName);
		featureDescriptor.setShortDescription(featureName);
		featureDescriptor.setExpert(false);
		featureDescriptor.setHidden(false);
		featureDescriptor.setPreferred(true);
		featureDescriptor.setValue(ELResolver.TYPE, classType);
		featureDescriptor.setValue(ELResolver.RESOLVABLE_AT_DESIGN_TIME, Boolean.TRUE);

		return featureDescriptor;
	}

	protected abstract PortletRequest getPortletRequest(FacesContext facesContext);

	protected abstract PortletResponse getPortletResponse(FacesContext facesContext);

	protected Object getFlash(FacesContext facesContext) {
		return facesContext.getExternalContext().getFlash();
	}

	protected boolean isFacesContextVar(String varName) {
		return false;
	}

	protected Object resolveVariable(ELContext elContext, String varName) {
		return null;
	}

	protected PortletConfig unwrapPortletConfig(PortletConfig portletConfig) {

		// Unwrap the PortletConfigWrapper to conform to the TCK's expectations. Note that this is not necessary with
		// JSR 378 since the TCK was modified to take BridgePortletConifigFactory into account. For more information,
		// see: https://issues.liferay.com/browse/FACES-3108
		while ((portletConfig instanceof FacesWrapper) && (portletConfig instanceof PortletConfig)) {
			FacesWrapper<PortletConfig> portletConfigWrapper = (FacesWrapper<PortletConfig>) portletConfig;
			portletConfig = portletConfigWrapper.getWrapped();
		}

		return portletConfig;
	}
}

==> com.liferay.faces.bridge.impl-4.1.4-sources.jar: com/liferay/faces/bridge/el/internal/ELResolverCompatImpl.java <==
/**
 * Copyright (c) 2000-2019 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.el.internal;

import java.beans.FeatureDescriptor;
import java.util.Collections;
import java.util.List;

import javax.el.ELContext;
import javax.el.ELResolver;
import javax.faces.FacesWrapper;
import javax.faces.context.FacesContext;
import javax.portlet.PortletConfig;
import javax.portlet.PortletRequest;
import javax.portlet.PortletResponse;


/**
 * This class provides a compatibility layer that isolates differences between JSF versions.
 *
 * @author  Neil Griffin
 */
public abstract class ELResolverCompatImpl extends ELResolver {

	// Protected Constants
	protected static final List<FeatureDescriptor> FEATURE_DESCRIPTORS_COMPAT;

	static {

		// Initialize the list of static feature descriptors.
		FEATURE_DESCRIPTORS_COMPAT = Collections.unmodifiableList(Collections.EMPTY_LIST);
	}

	protected static FeatureDescriptor getFeatureDescriptor(String featureName, Class<?> classType) {
		FeatureDescriptor featureDescriptor = new FeatureDescriptor();
		featureDescriptor.setName(featureName);
		featureDescriptor.setDisplayName(featureName);
		featureDescriptor.setShortDescription(featureName);
		featureDescriptor.setExpert(false);
		featureDescriptor.setHidden(false);
		featureDescriptor.setPreferred(true);
		featureDescriptor.setValue(ELResolver.TYPE, classType);
		featureDescriptor.setValue(ELResolver.RESOLVABLE_AT_DESIGN_TIME, Boolean.TRUE);

		return featureDescriptor;
	}

	protected abstract PortletRequest getPortletRequest(FacesContext facesContext);

	protected abstract PortletResponse getPortletResponse(FacesContext facesContext);

	protected Object getFlash(FacesContext facesContext) {
		return facesContext.getExternalContext().getFlash();
	}

	protected boolean isFacesContextVar(String varName) {
		return false;
	}

	protected Object resolveVariable(ELContext elContext, String varName) {
		return null;
	}

	protected PortletConfig unwrapPortletConfig(PortletConfig portletConfig) {

		// It is not necessary to unwrap the specified PortletConfig with JSR 378 since the TCK was modified to take
		// BridgePortletConifigFactory into account. For more information,
		// see: https://issues.liferay.com/browse/FACES-3108
		return portletConfig;
	}
}
